==> open-cluster-management-cluster-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterPredicateFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterPredicateFluentImpl<A extends ClusterPredicateFluent<A>> extends BaseFluent<A> implements ClusterPredicateFluent<A>{
  public ClusterPredicateFluentImpl() {
  }
  public ClusterPredicateFluentImpl(ClusterPredicate instance) {
    this.withRequiredClusterSelector(instance.getRequiredClusterSelector()); 
  }
  private ClusterSelectorBuilder requiredClusterSelector;
  
  /**
   * This method has been deprecated, please use method buildRequiredClusterSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterSelector getRequiredClusterSelector() {
    return this.requiredClusterSelector!=null ?this.requiredClusterSelector.build():null;
  }
  public ClusterSelector buildRequiredClusterSelector() {
    return this.requiredClusterSelector!=null ?this.requiredClusterSelector.build():null;
  }
  public A withRequiredClusterSelector(ClusterSelector requiredClusterSelector) {
    _visitables.get("requiredClusterSelector").remove(this.requiredClusterSelector);
    if (requiredClusterSelector!=null){ this.requiredClusterSelector= new ClusterSelectorBuilder(requiredClusterSelector); _visitables.get("requiredClusterSelector").add(this.requiredClusterSelector);} else { this.requiredClusterSelector = null; _visitables.get("requiredClusterSelector").remove(this.requiredClusterSelector); } return (A) this;
  }
  public Boolean hasRequiredClusterSelector() {
    return this.requiredClusterSelector != null;
  }
  public ClusterPredicateFluent.RequiredClusterSelectorNested<A> withNewRequiredClusterSelector() {
    return new ClusterPredicateFluentImpl.RequiredClusterSelectorNestedImpl();
  }
  public ClusterPredicateFluent.RequiredClusterSelectorNested<A> withNewRequiredClusterSelectorLike(ClusterSelector item) {
    return new ClusterPredicateFluentImpl.RequiredClusterSelectorNestedImpl(item);
  }
  public ClusterPredicateFluent.RequiredClusterSelectorNested<A> editRequiredClusterSelector() {
    return withNewRequiredClusterSelectorLike(getRequiredClusterSelector());
  }
  public ClusterPredicateFluent.RequiredClusterSelectorNested<A> editOrNewRequiredClusterSelector() {
    return withNewRequiredClusterSelectorLike(getRequiredClusterSelector() != null ? getRequiredClusterSelector(): new ClusterSelectorBuilder().build());
  }
  public ClusterPredicateFluent.RequiredClusterSelectorNested<A> editOrNewRequiredClusterSelectorLike(ClusterSelector item) {
    return withNewRequiredClusterSelectorLike(getRequiredClusterSelector() != null ? getRequiredClusterSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterPredicateFluentImpl that = (ClusterPredicateFluentImpl) o;
    if (requiredClusterSelector != null ? !requiredClusterSelector.equals(that.requiredClusterSelector) :that.requiredClusterSelector != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(requiredClusterSelector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (requiredClusterSelector != null) { sb.append("requiredClusterSelector:"); sb.append(requiredClusterSelector); }
    sb.append("}");
    return sb.toString();
  }
  class RequiredClusterSelectorNestedImpl<N> extends ClusterSelectorFluentImpl<ClusterPredicateFluent.RequiredClusterSelectorNested<N>> implements ClusterPredicateFluent.RequiredClusterSelectorNested<N>,Nested<N>{
    RequiredClusterSelectorNestedImpl(ClusterSelector item) {
      this.builder = new ClusterSelectorBuilder(this, item);
    }
    RequiredClusterSelectorNestedImpl() {
      this.builder = new ClusterSelectorBuilder(this);
    }
    ClusterSelectorBuilder builder;
    public N and() {
      return (N) ClusterPredicateFluentImpl.this.withRequiredClusterSelector(builder.build());
    }
    public N endRequiredClusterSelector() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-cluster-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1alpha1/ClusterPredicateFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterPredicateFluentImpl<A extends ClusterPredicateFluent<A>> extends BaseFluent<A> implements ClusterPredicateFluent<A>{
  public ClusterPredicateFluentImpl() {
  }
  public ClusterPredicateFluentImpl(ClusterPredicate instance) {
    if (instance != null) {
      this.withRequiredClusterSelector(instance.getRequiredClusterSelector());
    }
  }
  private ClusterSelectorBuilder requiredClusterSelector;
  
  /**
   * This method has been deprecated, please use method buildRequiredClusterSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterSelector getRequiredClusterSelector() {
    return this.requiredClusterSelector!=null ?this.requiredClusterSelector.build():null;
  }
  public ClusterSelector buildRequiredClusterSelector() {
    return this.requiredClusterSelector!=null ?this.requiredClusterSelector.build():null;
  }
  public A withRequiredClusterSelector(ClusterSelector requiredClusterSelector) {
    _visitables.get("requiredClusterSelector").remove(this.requiredClusterSelector);
    if (requiredClusterSelector!=null){ this.requiredClusterSelector= new ClusterSelectorBuilder(requiredClusterSelector); _visitables.get("requiredClusterSelector").add(this.requiredClusterSelector);} else { this.requiredClusterSelector = null; _visitables.get("requiredClusterSelector").remove(this.requiredClusterSelector); } return (A) this;
  }
  public Boolean hasRequiredClusterSelector() {
    return this.requiredClusterSelector != null;
  }
  public ClusterPredicateFluentImpl.RequiredClusterSelectorNested<A> withNewRequiredClusterSelector() {
    return new ClusterPredicateFluentImpl.RequiredClusterSelectorNestedImpl();
  }
  public ClusterPredicateFluentImpl.RequiredClusterSelectorNested<A> withNewRequiredClusterSelectorLike(ClusterSelector item) {
    return new ClusterPredicateFluentImpl.RequiredClusterSelectorNestedImpl(item);
  }
  public ClusterPredicateFluentImpl.RequiredClusterSelectorNested<A> editRequiredClusterSelector() {
    return withNewRequiredClusterSelectorLike(getRequiredClusterSelector());
  }
  public ClusterPredicateFluentImpl.RequiredClusterSelectorNested<A> editOrNewRequiredClusterSelector() {
    return withNewRequiredClusterSelectorLike(getRequiredClusterSelector() != null ? getRequiredClusterSelector(): new ClusterSelectorBuilder().build());
  }
  public ClusterPredicateFluentImpl.RequiredClusterSelectorNested<A> editOrNewRequiredClusterSelectorLike(ClusterSelector item) {
    return withNewRequiredClusterSelectorLike(getRequiredClusterSelector() != null ? getRequiredClusterSelector(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterPredicateFluentImpl that = (ClusterPredicateFluentImpl) o;
    if (!java.util.Objects.equals(requiredClusterSelector, that.requiredClusterSelector)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(requiredClusterSelector,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (requiredClusterSelector != null) { sb.append("requiredClusterSelector:"); sb.append(requiredClusterSelector); }
    sb.append("}");
    return sb.toString();
  }
  class RequiredClusterSelectorNestedImpl<N> extends ClusterSelectorFluentImpl<ClusterPredicateFluentImpl.RequiredClusterSelectorNested<N>> implements ClusterPredicateFluentImpl.RequiredClusterSelectorNested<N>,Nested<N>{
    RequiredClusterSelectorNestedImpl(ClusterSelector item) {
      this.builder = new ClusterSelectorBuilder(this, item);
    }
    RequiredClusterSelectorNestedImpl() {
      this.builder = new ClusterSelectorBuilder(this);
    }
    ClusterSelectorBuilder builder;
    public N and() {
      return (N) ClusterPredicateFluentImpl.this.withRequiredClusterSelector(builder.build());
    }
    public N endRequiredClusterSelector() {
      return and();
    }
    
  }
  
}
